**Example 1: 获取直播互动曲库歌手分类信息**



Input: 

```
tccli ame DescribeKTVSingerCategories --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "GenderSet": [
            {
                "EnglishName": "MALE",
                "ChineseName": "男"
            }
        ],
        "AreaSet": [
            {
                "EnglishName": "CH",
                "ChineseName": "中国大陆"
            }
        ],
        "RequestId": "xx"
    }
}
```

